# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class BigQueryTableSchema(UniversalBaseModel):
    """
    Schema for a BigQuery table
    """

    fields: typing.Optional[typing.List["BigQueryTableFieldSchema"]] = pydantic.Field(default=None)
    """
    List of table fields
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .big_query_table_field_schema import BigQueryTableFieldSchema  # noqa: E402, I001

update_forward_refs(BigQueryTableSchema)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .slack_reaction import SlackReaction


class SlackMessage(UniversalBaseModel):
    """
    Slack Message object
    """

    text: str = pydantic.Field()
    """
    Message text content
    """

    reactions: typing.Optional[typing.List[SlackReaction]] = pydantic.Field(default=None)
    """
    Reactions to this message
    """

    replies: typing.Optional[typing.List["SlackMessage"]] = pydantic.Field(default=None)
    """
    Thread replies to this message
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(SlackMessage)
